#!perl
###########################################################################
#
#   carp_fork.t
#
#   Copyright (C) 1999 Raphael Manfredi.
#   Copyright (C) 2002-2003, 2005, 2013 Mark Rogaski, mrogaski@cpan.org;
#   all rights reserved.
#
#   See the README file included with the
#   distribution for license information.
#
##########################################################################

use Log::Agent;
require Log::Agent::Driver::Fork;
require Log::Agent::Driver::File;

unlink 't/file.out', 't/file.err';

my $driver = Log::Agent::Driver::Fork->make(
    Log::Agent::Driver::File->make( 
        -prefix => 'me',
        -channels => {
            'error' => 't/file.err',
            'output' => 't/file.out'
        },
    )
);
logconfig(-driver => $driver);

do 't/carp.pl';

